@@ -5,6 +5,7 @@ Tasks used in processing signal handlers.
 import six
 from celery import shared_task
 from celery_utils.logged_task import LoggedTask
+from opaque_keys.edx.keys import CourseKey
 
 from django.conf import settings
 
@@ -19,8 +20,10 @@ def mark_all_stale(course_key, users=None):
     """
     Mark the specified enrollments as stale for all blocks.
     """
-    users = users or get_active_users(course_key)
-    stale_objects = [StaleCompletion(username=user.username, course_key=course_key, force=True) for user in users]
+    if isinstance(course_key, six.text_type):
+        course_key = CourseKey.from_string(course_key)
+    usernames = users or [user.username for user in get_active_users(course_key)]
+    stale_objects = [StaleCompletion(username=username, course_key=course_key, force=True) for username in usernames]
     StaleCompletion.objects.bulk_create(stale_objects, batch_size=1000)
     CacheGroup().delete_group(six.text_type(course_key))
 
